# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ChannelBinding.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'RenderingDef' not in _M_omero.model.__dict__:
    _M_omero.model._t_RenderingDef = IcePy.declareClass('::omero::model::RenderingDef')
    _M_omero.model._t_RenderingDefPrx = IcePy.declareProxy('::omero::model::RenderingDef')

if 'Family' not in _M_omero.model.__dict__:
    _M_omero.model._t_Family = IcePy.declareClass('::omero::model::Family')
    _M_omero.model._t_FamilyPrx = IcePy.declareProxy('::omero::model::Family')

if 'CodomainMapContext' not in _M_omero.model.__dict__:
    _M_omero.model._t_CodomainMapContext = IcePy.declareClass('::omero::model::CodomainMapContext')
    _M_omero.model._t_CodomainMapContextPrx = IcePy.declareProxy('::omero::model::CodomainMapContext')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_ChannelBindingSpatialDomainEnhancementSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ChannelBindingSpatialDomainEnhancementSeq = IcePy.defineSequence('::omero::model::ChannelBindingSpatialDomainEnhancementSeq', (), _M_omero.model._t_CodomainMapContext)

if 'ChannelBinding' not in _M_omero.model.__dict__:
    _M_omero.model.ChannelBinding = Ice.createTempClass()
    class ChannelBinding(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _renderingDef=None, _family=None, _coefficient=None, _inputStart=None, _inputEnd=None, _active=None, _noiseReduction=None, _red=None, _green=None, _blue=None, _alpha=None, _lookupTable=None, _spatialDomainEnhancementSeq=None, _spatialDomainEnhancementLoaded=False):
            if Ice.getType(self) == _M_omero.model.ChannelBinding:
                raise RuntimeError('omero.model.ChannelBinding is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._renderingDef = _renderingDef
            self._family = _family
            self._coefficient = _coefficient
            self._inputStart = _inputStart
            self._inputEnd = _inputEnd
            self._active = _active
            self._noiseReduction = _noiseReduction
            self._red = _red
            self._green = _green
            self._blue = _blue
            self._alpha = _alpha
            self._lookupTable = _lookupTable
            self._spatialDomainEnhancementSeq = _spatialDomainEnhancementSeq
            self._spatialDomainEnhancementLoaded = _spatialDomainEnhancementLoaded

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::ChannelBinding', '::omero::model::IObject')

        def ice_id(self, current=None):
            return '::omero::model::ChannelBinding'

        def ice_staticId():
            return '::omero::model::ChannelBinding'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getRenderingDef(self, current=None):
            pass

        def setRenderingDef(self, theRenderingDef, current=None):
            pass

        def getFamily(self, current=None):
            pass

        def setFamily(self, theFamily, current=None):
            pass

        def getCoefficient(self, current=None):
            pass

        def setCoefficient(self, theCoefficient, current=None):
            pass

        def getInputStart(self, current=None):
            pass

        def setInputStart(self, theInputStart, current=None):
            pass

        def getInputEnd(self, current=None):
            pass

        def setInputEnd(self, theInputEnd, current=None):
            pass

        def getActive(self, current=None):
            pass

        def setActive(self, theActive, current=None):
            pass

        def getNoiseReduction(self, current=None):
            pass

        def setNoiseReduction(self, theNoiseReduction, current=None):
            pass

        def getRed(self, current=None):
            pass

        def setRed(self, theRed, current=None):
            pass

        def getGreen(self, current=None):
            pass

        def setGreen(self, theGreen, current=None):
            pass

        def getBlue(self, current=None):
            pass

        def setBlue(self, theBlue, current=None):
            pass

        def getAlpha(self, current=None):
            pass

        def setAlpha(self, theAlpha, current=None):
            pass

        def getLookupTable(self, current=None):
            pass

        def setLookupTable(self, theLookupTable, current=None):
            pass

        def unloadSpatialDomainEnhancement(self, current=None):
            pass

        def sizeOfSpatialDomainEnhancement(self, current=None):
            pass

        def copySpatialDomainEnhancement(self, current=None):
            pass

        def addCodomainMapContext(self, target, current=None):
            pass

        def addAllCodomainMapContextSet(self, targets, current=None):
            pass

        def removeCodomainMapContext(self, theTarget, current=None):
            pass

        def removeAllCodomainMapContextSet(self, targets, current=None):
            pass

        def clearSpatialDomainEnhancement(self, current=None):
            pass

        def reloadSpatialDomainEnhancement(self, toCopy, current=None):
            pass

        def getCodomainMapContext(self, index, current=None):
            pass

        def setCodomainMapContext(self, index, theElement, current=None):
            pass

        def getPrimaryCodomainMapContext(self, current=None):
            pass

        def setPrimaryCodomainMapContext(self, theElement, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_ChannelBinding)

        __repr__ = __str__

    _M_omero.model.ChannelBindingPrx = Ice.createTempClass()
    class ChannelBindingPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.ChannelBinding._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.ChannelBinding._op_setVersion.end(self, _r)

        def getRenderingDef(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getRenderingDef.invoke(self, ((), _ctx))

        def begin_getRenderingDef(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getRenderingDef.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRenderingDef(self, _r):
            return _M_omero.model.ChannelBinding._op_getRenderingDef.end(self, _r)

        def setRenderingDef(self, theRenderingDef, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setRenderingDef.invoke(self, ((theRenderingDef, ), _ctx))

        def begin_setRenderingDef(self, theRenderingDef, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setRenderingDef.begin(self, ((theRenderingDef, ), _response, _ex, _sent, _ctx))

        def end_setRenderingDef(self, _r):
            return _M_omero.model.ChannelBinding._op_setRenderingDef.end(self, _r)

        def getFamily(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getFamily.invoke(self, ((), _ctx))

        def begin_getFamily(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getFamily.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFamily(self, _r):
            return _M_omero.model.ChannelBinding._op_getFamily.end(self, _r)

        def setFamily(self, theFamily, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setFamily.invoke(self, ((theFamily, ), _ctx))

        def begin_setFamily(self, theFamily, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setFamily.begin(self, ((theFamily, ), _response, _ex, _sent, _ctx))

        def end_setFamily(self, _r):
            return _M_omero.model.ChannelBinding._op_setFamily.end(self, _r)

        def getCoefficient(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getCoefficient.invoke(self, ((), _ctx))

        def begin_getCoefficient(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getCoefficient.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCoefficient(self, _r):
            return _M_omero.model.ChannelBinding._op_getCoefficient.end(self, _r)

        def setCoefficient(self, theCoefficient, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setCoefficient.invoke(self, ((theCoefficient, ), _ctx))

        def begin_setCoefficient(self, theCoefficient, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setCoefficient.begin(self, ((theCoefficient, ), _response, _ex, _sent, _ctx))

        def end_setCoefficient(self, _r):
            return _M_omero.model.ChannelBinding._op_setCoefficient.end(self, _r)

        def getInputStart(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getInputStart.invoke(self, ((), _ctx))

        def begin_getInputStart(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getInputStart.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getInputStart(self, _r):
            return _M_omero.model.ChannelBinding._op_getInputStart.end(self, _r)

        def setInputStart(self, theInputStart, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setInputStart.invoke(self, ((theInputStart, ), _ctx))

        def begin_setInputStart(self, theInputStart, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setInputStart.begin(self, ((theInputStart, ), _response, _ex, _sent, _ctx))

        def end_setInputStart(self, _r):
            return _M_omero.model.ChannelBinding._op_setInputStart.end(self, _r)

        def getInputEnd(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getInputEnd.invoke(self, ((), _ctx))

        def begin_getInputEnd(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getInputEnd.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getInputEnd(self, _r):
            return _M_omero.model.ChannelBinding._op_getInputEnd.end(self, _r)

        def setInputEnd(self, theInputEnd, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setInputEnd.invoke(self, ((theInputEnd, ), _ctx))

        def begin_setInputEnd(self, theInputEnd, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setInputEnd.begin(self, ((theInputEnd, ), _response, _ex, _sent, _ctx))

        def end_setInputEnd(self, _r):
            return _M_omero.model.ChannelBinding._op_setInputEnd.end(self, _r)

        def getActive(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getActive.invoke(self, ((), _ctx))

        def begin_getActive(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getActive.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getActive(self, _r):
            return _M_omero.model.ChannelBinding._op_getActive.end(self, _r)

        def setActive(self, theActive, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setActive.invoke(self, ((theActive, ), _ctx))

        def begin_setActive(self, theActive, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setActive.begin(self, ((theActive, ), _response, _ex, _sent, _ctx))

        def end_setActive(self, _r):
            return _M_omero.model.ChannelBinding._op_setActive.end(self, _r)

        def getNoiseReduction(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getNoiseReduction.invoke(self, ((), _ctx))

        def begin_getNoiseReduction(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getNoiseReduction.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getNoiseReduction(self, _r):
            return _M_omero.model.ChannelBinding._op_getNoiseReduction.end(self, _r)

        def setNoiseReduction(self, theNoiseReduction, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setNoiseReduction.invoke(self, ((theNoiseReduction, ), _ctx))

        def begin_setNoiseReduction(self, theNoiseReduction, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setNoiseReduction.begin(self, ((theNoiseReduction, ), _response, _ex, _sent, _ctx))

        def end_setNoiseReduction(self, _r):
            return _M_omero.model.ChannelBinding._op_setNoiseReduction.end(self, _r)

        def getRed(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getRed.invoke(self, ((), _ctx))

        def begin_getRed(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getRed.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRed(self, _r):
            return _M_omero.model.ChannelBinding._op_getRed.end(self, _r)

        def setRed(self, theRed, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setRed.invoke(self, ((theRed, ), _ctx))

        def begin_setRed(self, theRed, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setRed.begin(self, ((theRed, ), _response, _ex, _sent, _ctx))

        def end_setRed(self, _r):
            return _M_omero.model.ChannelBinding._op_setRed.end(self, _r)

        def getGreen(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getGreen.invoke(self, ((), _ctx))

        def begin_getGreen(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getGreen.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getGreen(self, _r):
            return _M_omero.model.ChannelBinding._op_getGreen.end(self, _r)

        def setGreen(self, theGreen, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setGreen.invoke(self, ((theGreen, ), _ctx))

        def begin_setGreen(self, theGreen, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setGreen.begin(self, ((theGreen, ), _response, _ex, _sent, _ctx))

        def end_setGreen(self, _r):
            return _M_omero.model.ChannelBinding._op_setGreen.end(self, _r)

        def getBlue(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getBlue.invoke(self, ((), _ctx))

        def begin_getBlue(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getBlue.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getBlue(self, _r):
            return _M_omero.model.ChannelBinding._op_getBlue.end(self, _r)

        def setBlue(self, theBlue, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setBlue.invoke(self, ((theBlue, ), _ctx))

        def begin_setBlue(self, theBlue, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setBlue.begin(self, ((theBlue, ), _response, _ex, _sent, _ctx))

        def end_setBlue(self, _r):
            return _M_omero.model.ChannelBinding._op_setBlue.end(self, _r)

        def getAlpha(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getAlpha.invoke(self, ((), _ctx))

        def begin_getAlpha(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getAlpha.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAlpha(self, _r):
            return _M_omero.model.ChannelBinding._op_getAlpha.end(self, _r)

        def setAlpha(self, theAlpha, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setAlpha.invoke(self, ((theAlpha, ), _ctx))

        def begin_setAlpha(self, theAlpha, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setAlpha.begin(self, ((theAlpha, ), _response, _ex, _sent, _ctx))

        def end_setAlpha(self, _r):
            return _M_omero.model.ChannelBinding._op_setAlpha.end(self, _r)

        def getLookupTable(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getLookupTable.invoke(self, ((), _ctx))

        def begin_getLookupTable(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getLookupTable.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLookupTable(self, _r):
            return _M_omero.model.ChannelBinding._op_getLookupTable.end(self, _r)

        def setLookupTable(self, theLookupTable, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setLookupTable.invoke(self, ((theLookupTable, ), _ctx))

        def begin_setLookupTable(self, theLookupTable, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setLookupTable.begin(self, ((theLookupTable, ), _response, _ex, _sent, _ctx))

        def end_setLookupTable(self, _r):
            return _M_omero.model.ChannelBinding._op_setLookupTable.end(self, _r)

        def unloadSpatialDomainEnhancement(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_unloadSpatialDomainEnhancement.invoke(self, ((), _ctx))

        def begin_unloadSpatialDomainEnhancement(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_unloadSpatialDomainEnhancement.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadSpatialDomainEnhancement(self, _r):
            return _M_omero.model.ChannelBinding._op_unloadSpatialDomainEnhancement.end(self, _r)

        def sizeOfSpatialDomainEnhancement(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_sizeOfSpatialDomainEnhancement.invoke(self, ((), _ctx))

        def begin_sizeOfSpatialDomainEnhancement(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_sizeOfSpatialDomainEnhancement.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfSpatialDomainEnhancement(self, _r):
            return _M_omero.model.ChannelBinding._op_sizeOfSpatialDomainEnhancement.end(self, _r)

        def copySpatialDomainEnhancement(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_copySpatialDomainEnhancement.invoke(self, ((), _ctx))

        def begin_copySpatialDomainEnhancement(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_copySpatialDomainEnhancement.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copySpatialDomainEnhancement(self, _r):
            return _M_omero.model.ChannelBinding._op_copySpatialDomainEnhancement.end(self, _r)

        def addCodomainMapContext(self, target, _ctx=None):
            return _M_omero.model.ChannelBinding._op_addCodomainMapContext.invoke(self, ((target, ), _ctx))

        def begin_addCodomainMapContext(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_addCodomainMapContext.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addCodomainMapContext(self, _r):
            return _M_omero.model.ChannelBinding._op_addCodomainMapContext.end(self, _r)

        def addAllCodomainMapContextSet(self, targets, _ctx=None):
            return _M_omero.model.ChannelBinding._op_addAllCodomainMapContextSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllCodomainMapContextSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_addAllCodomainMapContextSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllCodomainMapContextSet(self, _r):
            return _M_omero.model.ChannelBinding._op_addAllCodomainMapContextSet.end(self, _r)

        def removeCodomainMapContext(self, theTarget, _ctx=None):
            return _M_omero.model.ChannelBinding._op_removeCodomainMapContext.invoke(self, ((theTarget, ), _ctx))

        def begin_removeCodomainMapContext(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_removeCodomainMapContext.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeCodomainMapContext(self, _r):
            return _M_omero.model.ChannelBinding._op_removeCodomainMapContext.end(self, _r)

        def removeAllCodomainMapContextSet(self, targets, _ctx=None):
            return _M_omero.model.ChannelBinding._op_removeAllCodomainMapContextSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllCodomainMapContextSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_removeAllCodomainMapContextSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllCodomainMapContextSet(self, _r):
            return _M_omero.model.ChannelBinding._op_removeAllCodomainMapContextSet.end(self, _r)

        def clearSpatialDomainEnhancement(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_clearSpatialDomainEnhancement.invoke(self, ((), _ctx))

        def begin_clearSpatialDomainEnhancement(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_clearSpatialDomainEnhancement.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearSpatialDomainEnhancement(self, _r):
            return _M_omero.model.ChannelBinding._op_clearSpatialDomainEnhancement.end(self, _r)

        def reloadSpatialDomainEnhancement(self, toCopy, _ctx=None):
            return _M_omero.model.ChannelBinding._op_reloadSpatialDomainEnhancement.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadSpatialDomainEnhancement(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_reloadSpatialDomainEnhancement.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadSpatialDomainEnhancement(self, _r):
            return _M_omero.model.ChannelBinding._op_reloadSpatialDomainEnhancement.end(self, _r)

        def getCodomainMapContext(self, index, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getCodomainMapContext.invoke(self, ((index, ), _ctx))

        def begin_getCodomainMapContext(self, index, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getCodomainMapContext.begin(self, ((index, ), _response, _ex, _sent, _ctx))

        def end_getCodomainMapContext(self, _r):
            return _M_omero.model.ChannelBinding._op_getCodomainMapContext.end(self, _r)

        def setCodomainMapContext(self, index, theElement, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setCodomainMapContext.invoke(self, ((index, theElement), _ctx))

        def begin_setCodomainMapContext(self, index, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setCodomainMapContext.begin(self, ((index, theElement), _response, _ex, _sent, _ctx))

        def end_setCodomainMapContext(self, _r):
            return _M_omero.model.ChannelBinding._op_setCodomainMapContext.end(self, _r)

        def getPrimaryCodomainMapContext(self, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getPrimaryCodomainMapContext.invoke(self, ((), _ctx))

        def begin_getPrimaryCodomainMapContext(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_getPrimaryCodomainMapContext.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPrimaryCodomainMapContext(self, _r):
            return _M_omero.model.ChannelBinding._op_getPrimaryCodomainMapContext.end(self, _r)

        def setPrimaryCodomainMapContext(self, theElement, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setPrimaryCodomainMapContext.invoke(self, ((theElement, ), _ctx))

        def begin_setPrimaryCodomainMapContext(self, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ChannelBinding._op_setPrimaryCodomainMapContext.begin(self, ((theElement, ), _response, _ex, _sent, _ctx))

        def end_setPrimaryCodomainMapContext(self, _r):
            return _M_omero.model.ChannelBinding._op_setPrimaryCodomainMapContext.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ChannelBindingPrx.ice_checkedCast(proxy, '::omero::model::ChannelBinding', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ChannelBindingPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::ChannelBinding'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ChannelBindingPrx = IcePy.defineProxy('::omero::model::ChannelBinding', ChannelBindingPrx)

    _M_omero.model._t_ChannelBinding = IcePy.declareClass('::omero::model::ChannelBinding')

    _M_omero.model._t_ChannelBinding = IcePy.defineClass('::omero::model::ChannelBinding', ChannelBinding, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_renderingDef', (), _M_omero.model._t_RenderingDef, False, 0),
        ('_family', (), _M_omero.model._t_Family, False, 0),
        ('_coefficient', (), _M_omero._t_RDouble, False, 0),
        ('_inputStart', (), _M_omero._t_RDouble, False, 0),
        ('_inputEnd', (), _M_omero._t_RDouble, False, 0),
        ('_active', (), _M_omero._t_RBool, False, 0),
        ('_noiseReduction', (), _M_omero._t_RBool, False, 0),
        ('_red', (), _M_omero._t_RInt, False, 0),
        ('_green', (), _M_omero._t_RInt, False, 0),
        ('_blue', (), _M_omero._t_RInt, False, 0),
        ('_alpha', (), _M_omero._t_RInt, False, 0),
        ('_lookupTable', (), _M_omero._t_RString, False, 0),
        ('_spatialDomainEnhancementSeq', (), _M_omero.model._t_ChannelBindingSpatialDomainEnhancementSeq, False, 0),
        ('_spatialDomainEnhancementLoaded', (), IcePy._t_bool, False, 0)
    ))
    ChannelBinding._ice_type = _M_omero.model._t_ChannelBinding

    ChannelBinding._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ChannelBinding._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ChannelBinding._op_getRenderingDef = IcePy.Operation('getRenderingDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RenderingDef, False, 0), ())
    ChannelBinding._op_setRenderingDef = IcePy.Operation('setRenderingDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDef, False, 0),), (), None, ())
    ChannelBinding._op_getFamily = IcePy.Operation('getFamily', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Family, False, 0), ())
    ChannelBinding._op_setFamily = IcePy.Operation('setFamily', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Family, False, 0),), (), None, ())
    ChannelBinding._op_getCoefficient = IcePy.Operation('getCoefficient', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    ChannelBinding._op_setCoefficient = IcePy.Operation('setCoefficient', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    ChannelBinding._op_getInputStart = IcePy.Operation('getInputStart', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    ChannelBinding._op_setInputStart = IcePy.Operation('setInputStart', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    ChannelBinding._op_getInputEnd = IcePy.Operation('getInputEnd', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    ChannelBinding._op_setInputEnd = IcePy.Operation('setInputEnd', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    ChannelBinding._op_getActive = IcePy.Operation('getActive', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RBool, False, 0), ())
    ChannelBinding._op_setActive = IcePy.Operation('setActive', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RBool, False, 0),), (), None, ())
    ChannelBinding._op_getNoiseReduction = IcePy.Operation('getNoiseReduction', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RBool, False, 0), ())
    ChannelBinding._op_setNoiseReduction = IcePy.Operation('setNoiseReduction', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RBool, False, 0),), (), None, ())
    ChannelBinding._op_getRed = IcePy.Operation('getRed', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ChannelBinding._op_setRed = IcePy.Operation('setRed', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ChannelBinding._op_getGreen = IcePy.Operation('getGreen', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ChannelBinding._op_setGreen = IcePy.Operation('setGreen', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ChannelBinding._op_getBlue = IcePy.Operation('getBlue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ChannelBinding._op_setBlue = IcePy.Operation('setBlue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ChannelBinding._op_getAlpha = IcePy.Operation('getAlpha', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ChannelBinding._op_setAlpha = IcePy.Operation('setAlpha', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ChannelBinding._op_getLookupTable = IcePy.Operation('getLookupTable', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    ChannelBinding._op_setLookupTable = IcePy.Operation('setLookupTable', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    ChannelBinding._op_unloadSpatialDomainEnhancement = IcePy.Operation('unloadSpatialDomainEnhancement', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    ChannelBinding._op_sizeOfSpatialDomainEnhancement = IcePy.Operation('sizeOfSpatialDomainEnhancement', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    ChannelBinding._op_copySpatialDomainEnhancement = IcePy.Operation('copySpatialDomainEnhancement', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ChannelBindingSpatialDomainEnhancementSeq, False, 0), ())
    ChannelBinding._op_addCodomainMapContext = IcePy.Operation('addCodomainMapContext', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_CodomainMapContext, False, 0),), (), None, ())
    ChannelBinding._op_addAllCodomainMapContextSet = IcePy.Operation('addAllCodomainMapContextSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ChannelBindingSpatialDomainEnhancementSeq, False, 0),), (), None, ())
    ChannelBinding._op_removeCodomainMapContext = IcePy.Operation('removeCodomainMapContext', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_CodomainMapContext, False, 0),), (), None, ())
    ChannelBinding._op_removeAllCodomainMapContextSet = IcePy.Operation('removeAllCodomainMapContextSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ChannelBindingSpatialDomainEnhancementSeq, False, 0),), (), None, ())
    ChannelBinding._op_clearSpatialDomainEnhancement = IcePy.Operation('clearSpatialDomainEnhancement', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    ChannelBinding._op_reloadSpatialDomainEnhancement = IcePy.Operation('reloadSpatialDomainEnhancement', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ChannelBinding, False, 0),), (), None, ())
    ChannelBinding._op_getCodomainMapContext = IcePy.Operation('getCodomainMapContext', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0),), (), ((), _M_omero.model._t_CodomainMapContext, False, 0), ())
    ChannelBinding._op_setCodomainMapContext = IcePy.Operation('setCodomainMapContext', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), _M_omero.model._t_CodomainMapContext, False, 0)), (), ((), _M_omero.model._t_CodomainMapContext, False, 0), ())
    ChannelBinding._op_getPrimaryCodomainMapContext = IcePy.Operation('getPrimaryCodomainMapContext', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_CodomainMapContext, False, 0), ())
    ChannelBinding._op_setPrimaryCodomainMapContext = IcePy.Operation('setPrimaryCodomainMapContext', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_CodomainMapContext, False, 0),), (), ((), _M_omero.model._t_CodomainMapContext, False, 0), ())

    _M_omero.model.ChannelBinding = ChannelBinding
    del ChannelBinding

    _M_omero.model.ChannelBindingPrx = ChannelBindingPrx
    del ChannelBindingPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Annotation.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'AnnotationAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_AnnotationAnnotationLink = IcePy.declareClass('::omero::model::AnnotationAnnotationLink')
    _M_omero.model._t_AnnotationAnnotationLinkPrx = IcePy.declareProxy('::omero::model::AnnotationAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_AnnotationAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_AnnotationAnnotationLinksSeq = IcePy.defineSequence('::omero::model::AnnotationAnnotationLinksSeq', (), _M_omero.model._t_AnnotationAnnotationLink)

if '_t_AnnotationLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_AnnotationLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::AnnotationLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model.Annotation = Ice.createTempClass()
    class Annotation(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _ns=None, _name=None, _description=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None):
            if Ice.getType(self) == _M_omero.model.Annotation:
                raise RuntimeError('omero.model.Annotation is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._ns = _ns
            self._name = _name
            self._description = _description
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::Annotation', '::omero::model::IObject')

        def ice_id(self, current=None):
            return '::omero::model::Annotation'

        def ice_staticId():
            return '::omero::model::Annotation'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getNs(self, current=None):
            pass

        def setNs(self, theNs, current=None):
            pass

        def getName(self, current=None):
            pass

        def setName(self, theName, current=None):
            pass

        def getDescription(self, current=None):
            pass

        def setDescription(self, theDescription, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addAnnotationAnnotationLink(self, target, current=None):
            pass

        def addAllAnnotationAnnotationLinkSet(self, targets, current=None):
            pass

        def removeAnnotationAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllAnnotationAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addAnnotationAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findAnnotationAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeAnnotationAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Annotation)

        __repr__ = __str__

    _M_omero.model.AnnotationPrx = Ice.createTempClass()
    class AnnotationPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Annotation._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Annotation._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Annotation._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Annotation._op_setVersion.end(self, _r)

        def getNs(self, _ctx=None):
            return _M_omero.model.Annotation._op_getNs.invoke(self, ((), _ctx))

        def begin_getNs(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_getNs.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getNs(self, _r):
            return _M_omero.model.Annotation._op_getNs.end(self, _r)

        def setNs(self, theNs, _ctx=None):
            return _M_omero.model.Annotation._op_setNs.invoke(self, ((theNs, ), _ctx))

        def begin_setNs(self, theNs, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_setNs.begin(self, ((theNs, ), _response, _ex, _sent, _ctx))

        def end_setNs(self, _r):
            return _M_omero.model.Annotation._op_setNs.end(self, _r)

        def getName(self, _ctx=None):
            return _M_omero.model.Annotation._op_getName.invoke(self, ((), _ctx))

        def begin_getName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_getName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getName(self, _r):
            return _M_omero.model.Annotation._op_getName.end(self, _r)

        def setName(self, theName, _ctx=None):
            return _M_omero.model.Annotation._op_setName.invoke(self, ((theName, ), _ctx))

        def begin_setName(self, theName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_setName.begin(self, ((theName, ), _response, _ex, _sent, _ctx))

        def end_setName(self, _r):
            return _M_omero.model.Annotation._op_setName.end(self, _r)

        def getDescription(self, _ctx=None):
            return _M_omero.model.Annotation._op_getDescription.invoke(self, ((), _ctx))

        def begin_getDescription(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_getDescription.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDescription(self, _r):
            return _M_omero.model.Annotation._op_getDescription.end(self, _r)

        def setDescription(self, theDescription, _ctx=None):
            return _M_omero.model.Annotation._op_setDescription.invoke(self, ((theDescription, ), _ctx))

        def begin_setDescription(self, theDescription, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_setDescription.begin(self, ((theDescription, ), _response, _ex, _sent, _ctx))

        def end_setDescription(self, _r):
            return _M_omero.model.Annotation._op_setDescription.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Annotation._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.Annotation._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Annotation._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.Annotation._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Annotation._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.Annotation._op_copyAnnotationLinks.end(self, _r)

        def addAnnotationAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.Annotation._op_addAnnotationAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addAnnotationAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_addAnnotationAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addAnnotationAnnotationLink(self, _r):
            return _M_omero.model.Annotation._op_addAnnotationAnnotationLink.end(self, _r)

        def addAllAnnotationAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Annotation._op_addAllAnnotationAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllAnnotationAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_addAllAnnotationAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllAnnotationAnnotationLinkSet(self, _r):
            return _M_omero.model.Annotation._op_addAllAnnotationAnnotationLinkSet.end(self, _r)

        def removeAnnotationAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.Annotation._op_removeAnnotationAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeAnnotationAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_removeAnnotationAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeAnnotationAnnotationLink(self, _r):
            return _M_omero.model.Annotation._op_removeAnnotationAnnotationLink.end(self, _r)

        def removeAllAnnotationAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Annotation._op_removeAllAnnotationAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllAnnotationAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_removeAllAnnotationAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllAnnotationAnnotationLinkSet(self, _r):
            return _M_omero.model.Annotation._op_removeAllAnnotationAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Annotation._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.Annotation._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Annotation._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.Annotation._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Annotation._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.Annotation._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.Annotation._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.Annotation._op_linkAnnotation.end(self, _r)

        def addAnnotationAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Annotation._op_addAnnotationAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addAnnotationAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_addAnnotationAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addAnnotationAnnotationLinkToBoth(self, _r):
            return _M_omero.model.Annotation._op_addAnnotationAnnotationLinkToBoth.end(self, _r)

        def findAnnotationAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.Annotation._op_findAnnotationAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findAnnotationAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_findAnnotationAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findAnnotationAnnotationLink(self, _r):
            return _M_omero.model.Annotation._op_findAnnotationAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.Annotation._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.Annotation._op_unlinkAnnotation.end(self, _r)

        def removeAnnotationAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Annotation._op_removeAnnotationAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeAnnotationAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_removeAnnotationAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeAnnotationAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.Annotation._op_removeAnnotationAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.Annotation._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Annotation._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.Annotation._op_linkedAnnotationList.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.AnnotationPrx.ice_checkedCast(proxy, '::omero::model::Annotation', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.AnnotationPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Annotation'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_AnnotationPrx = IcePy.defineProxy('::omero::model::Annotation', AnnotationPrx)

    _M_omero.model._t_Annotation = IcePy.defineClass('::omero::model::Annotation', Annotation, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_ns', (), _M_omero._t_RString, False, 0),
        ('_name', (), _M_omero._t_RString, False, 0),
        ('_description', (), _M_omero._t_RString, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_AnnotationAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0)
    ))
    Annotation._ice_type = _M_omero.model._t_Annotation

    Annotation._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Annotation._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Annotation._op_getNs = IcePy.Operation('getNs', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Annotation._op_setNs = IcePy.Operation('setNs', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Annotation._op_getName = IcePy.Operation('getName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Annotation._op_setName = IcePy.Operation('setName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Annotation._op_getDescription = IcePy.Operation('getDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Annotation._op_setDescription = IcePy.Operation('setDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Annotation._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Annotation._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Annotation._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_AnnotationAnnotationLinksSeq, False, 0), ())
    Annotation._op_addAnnotationAnnotationLink = IcePy.Operation('addAnnotationAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_AnnotationAnnotationLink, False, 0),), (), None, ())
    Annotation._op_addAllAnnotationAnnotationLinkSet = IcePy.Operation('addAllAnnotationAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_AnnotationAnnotationLinksSeq, False, 0),), (), None, ())
    Annotation._op_removeAnnotationAnnotationLink = IcePy.Operation('removeAnnotationAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_AnnotationAnnotationLink, False, 0),), (), None, ())
    Annotation._op_removeAllAnnotationAnnotationLinkSet = IcePy.Operation('removeAllAnnotationAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_AnnotationAnnotationLinksSeq, False, 0),), (), None, ())
    Annotation._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Annotation._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Annotation._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Annotation._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_AnnotationAnnotationLink, False, 0), ())
    Annotation._op_addAnnotationAnnotationLinkToBoth = IcePy.Operation('addAnnotationAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_AnnotationAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Annotation._op_findAnnotationAnnotationLink = IcePy.Operation('findAnnotationAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_AnnotationAnnotationLinksSeq, False, 0), ())
    Annotation._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Annotation._op_removeAnnotationAnnotationLinkFromBoth = IcePy.Operation('removeAnnotationAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_AnnotationAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Annotation._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_AnnotationLinkedAnnotationSeq, False, 0), ())

    _M_omero.model.Annotation = Annotation
    del Annotation

    _M_omero.model.AnnotationPrx = AnnotationPrx
    del AnnotationPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `LightSettings.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'LightSource' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightSource = IcePy.declareClass('::omero::model::LightSource')
    _M_omero.model._t_LightSourcePrx = IcePy.declareProxy('::omero::model::LightSource')

if 'MicrobeamManipulation' not in _M_omero.model.__dict__:
    _M_omero.model._t_MicrobeamManipulation = IcePy.declareClass('::omero::model::MicrobeamManipulation')
    _M_omero.model._t_MicrobeamManipulationPrx = IcePy.declareProxy('::omero::model::MicrobeamManipulation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'LightSettings' not in _M_omero.model.__dict__:
    _M_omero.model.LightSettings = Ice.createTempClass()
    class LightSettings(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _attenuation=None, _wavelength=None, _lightSource=None, _microbeamManipulation=None):
            if Ice.getType(self) == _M_omero.model.LightSettings:
                raise RuntimeError('omero.model.LightSettings is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._attenuation = _attenuation
            self._wavelength = _wavelength
            self._lightSource = _lightSource
            self._microbeamManipulation = _microbeamManipulation

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::LightSettings')

        def ice_id(self, current=None):
            return '::omero::model::LightSettings'

        def ice_staticId():
            return '::omero::model::LightSettings'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getAttenuation(self, current=None):
            pass

        def setAttenuation(self, theAttenuation, current=None):
            pass

        def getWavelength(self, current=None):
            pass

        def setWavelength(self, theWavelength, current=None):
            pass

        def getLightSource(self, current=None):
            pass

        def setLightSource(self, theLightSource, current=None):
            pass

        def getMicrobeamManipulation(self, current=None):
            pass

        def setMicrobeamManipulation(self, theMicrobeamManipulation, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_LightSettings)

        __repr__ = __str__

    _M_omero.model.LightSettingsPrx = Ice.createTempClass()
    class LightSettingsPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.LightSettings._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.LightSettings._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.LightSettings._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.LightSettings._op_setVersion.end(self, _r)

        def getAttenuation(self, _ctx=None):
            return _M_omero.model.LightSettings._op_getAttenuation.invoke(self, ((), _ctx))

        def begin_getAttenuation(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_getAttenuation.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAttenuation(self, _r):
            return _M_omero.model.LightSettings._op_getAttenuation.end(self, _r)

        def setAttenuation(self, theAttenuation, _ctx=None):
            return _M_omero.model.LightSettings._op_setAttenuation.invoke(self, ((theAttenuation, ), _ctx))

        def begin_setAttenuation(self, theAttenuation, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_setAttenuation.begin(self, ((theAttenuation, ), _response, _ex, _sent, _ctx))

        def end_setAttenuation(self, _r):
            return _M_omero.model.LightSettings._op_setAttenuation.end(self, _r)

        def getWavelength(self, _ctx=None):
            return _M_omero.model.LightSettings._op_getWavelength.invoke(self, ((), _ctx))

        def begin_getWavelength(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_getWavelength.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getWavelength(self, _r):
            return _M_omero.model.LightSettings._op_getWavelength.end(self, _r)

        def setWavelength(self, theWavelength, _ctx=None):
            return _M_omero.model.LightSettings._op_setWavelength.invoke(self, ((theWavelength, ), _ctx))

        def begin_setWavelength(self, theWavelength, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_setWavelength.begin(self, ((theWavelength, ), _response, _ex, _sent, _ctx))

        def end_setWavelength(self, _r):
            return _M_omero.model.LightSettings._op_setWavelength.end(self, _r)

        def getLightSource(self, _ctx=None):
            return _M_omero.model.LightSettings._op_getLightSource.invoke(self, ((), _ctx))

        def begin_getLightSource(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_getLightSource.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLightSource(self, _r):
            return _M_omero.model.LightSettings._op_getLightSource.end(self, _r)

        def setLightSource(self, theLightSource, _ctx=None):
            return _M_omero.model.LightSettings._op_setLightSource.invoke(self, ((theLightSource, ), _ctx))

        def begin_setLightSource(self, theLightSource, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_setLightSource.begin(self, ((theLightSource, ), _response, _ex, _sent, _ctx))

        def end_setLightSource(self, _r):
            return _M_omero.model.LightSettings._op_setLightSource.end(self, _r)

        def getMicrobeamManipulation(self, _ctx=None):
            return _M_omero.model.LightSettings._op_getMicrobeamManipulation.invoke(self, ((), _ctx))

        def begin_getMicrobeamManipulation(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_getMicrobeamManipulation.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMicrobeamManipulation(self, _r):
            return _M_omero.model.LightSettings._op_getMicrobeamManipulation.end(self, _r)

        def setMicrobeamManipulation(self, theMicrobeamManipulation, _ctx=None):
            return _M_omero.model.LightSettings._op_setMicrobeamManipulation.invoke(self, ((theMicrobeamManipulation, ), _ctx))

        def begin_setMicrobeamManipulation(self, theMicrobeamManipulation, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_setMicrobeamManipulation.begin(self, ((theMicrobeamManipulation, ), _response, _ex, _sent, _ctx))

        def end_setMicrobeamManipulation(self, _r):
            return _M_omero.model.LightSettings._op_setMicrobeamManipulation.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.LightSettingsPrx.ice_checkedCast(proxy, '::omero::model::LightSettings', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.LightSettingsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::LightSettings'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_LightSettingsPrx = IcePy.defineProxy('::omero::model::LightSettings', LightSettingsPrx)

    _M_omero.model._t_LightSettings = IcePy.declareClass('::omero::model::LightSettings')

    _M_omero.model._t_LightSettings = IcePy.defineClass('::omero::model::LightSettings', LightSettings, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_attenuation', (), _M_omero._t_RDouble, False, 0),
        ('_wavelength', (), _M_omero.model._t_Length, False, 0),
        ('_lightSource', (), _M_omero.model._t_LightSource, False, 0),
        ('_microbeamManipulation', (), _M_omero.model._t_MicrobeamManipulation, False, 0)
    ))
    LightSettings._ice_type = _M_omero.model._t_LightSettings

    LightSettings._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    LightSettings._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    LightSettings._op_getAttenuation = IcePy.Operation('getAttenuation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    LightSettings._op_setAttenuation = IcePy.Operation('setAttenuation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    LightSettings._op_getWavelength = IcePy.Operation('getWavelength', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    LightSettings._op_setWavelength = IcePy.Operation('setWavelength', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    LightSettings._op_getLightSource = IcePy.Operation('getLightSource', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightSource, False, 0), ())
    LightSettings._op_setLightSource = IcePy.Operation('setLightSource', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightSource, False, 0),), (), None, ())
    LightSettings._op_getMicrobeamManipulation = IcePy.Operation('getMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_MicrobeamManipulation, False, 0), ())
    LightSettings._op_setMicrobeamManipulation = IcePy.Operation('setMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_MicrobeamManipulation, False, 0),), (), None, ())

    _M_omero.model.LightSettings = LightSettings
    del LightSettings

    _M_omero.model.LightSettingsPrx = LightSettingsPrx
    del LightSettingsPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `WellSample.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'PlateAcquisition' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlateAcquisition = IcePy.declareClass('::omero::model::PlateAcquisition')
    _M_omero.model._t_PlateAcquisitionPrx = IcePy.declareProxy('::omero::model::PlateAcquisition')

if 'Well' not in _M_omero.model.__dict__:
    _M_omero.model._t_Well = IcePy.declareClass('::omero::model::Well')
    _M_omero.model._t_WellPrx = IcePy.declareProxy('::omero::model::Well')

if 'Image' not in _M_omero.model.__dict__:
    _M_omero.model._t_Image = IcePy.declareClass('::omero::model::Image')
    _M_omero.model._t_ImagePrx = IcePy.declareProxy('::omero::model::Image')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'WellSample' not in _M_omero.model.__dict__:
    _M_omero.model.WellSample = Ice.createTempClass()
    class WellSample(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _posX=None, _posY=None, _timepoint=None, _plateAcquisition=None, _well=None, _image=None):
            if Ice.getType(self) == _M_omero.model.WellSample:
                raise RuntimeError('omero.model.WellSample is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._posX = _posX
            self._posY = _posY
            self._timepoint = _timepoint
            self._plateAcquisition = _plateAcquisition
            self._well = _well
            self._image = _image

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::WellSample')

        def ice_id(self, current=None):
            return '::omero::model::WellSample'

        def ice_staticId():
            return '::omero::model::WellSample'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getPosX(self, current=None):
            pass

        def setPosX(self, thePosX, current=None):
            pass

        def getPosY(self, current=None):
            pass

        def setPosY(self, thePosY, current=None):
            pass

        def getTimepoint(self, current=None):
            pass

        def setTimepoint(self, theTimepoint, current=None):
            pass

        def getPlateAcquisition(self, current=None):
            pass

        def setPlateAcquisition(self, thePlateAcquisition, current=None):
            pass

        def getWell(self, current=None):
            pass

        def setWell(self, theWell, current=None):
            pass

        def getImage(self, current=None):
            pass

        def setImage(self, theImage, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_WellSample)

        __repr__ = __str__

    _M_omero.model.WellSamplePrx = Ice.createTempClass()
    class WellSamplePrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.WellSample._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.WellSample._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.WellSample._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.WellSample._op_setVersion.end(self, _r)

        def getPosX(self, _ctx=None):
            return _M_omero.model.WellSample._op_getPosX.invoke(self, ((), _ctx))

        def begin_getPosX(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_getPosX.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPosX(self, _r):
            return _M_omero.model.WellSample._op_getPosX.end(self, _r)

        def setPosX(self, thePosX, _ctx=None):
            return _M_omero.model.WellSample._op_setPosX.invoke(self, ((thePosX, ), _ctx))

        def begin_setPosX(self, thePosX, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_setPosX.begin(self, ((thePosX, ), _response, _ex, _sent, _ctx))

        def end_setPosX(self, _r):
            return _M_omero.model.WellSample._op_setPosX.end(self, _r)

        def getPosY(self, _ctx=None):
            return _M_omero.model.WellSample._op_getPosY.invoke(self, ((), _ctx))

        def begin_getPosY(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_getPosY.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPosY(self, _r):
            return _M_omero.model.WellSample._op_getPosY.end(self, _r)

        def setPosY(self, thePosY, _ctx=None):
            return _M_omero.model.WellSample._op_setPosY.invoke(self, ((thePosY, ), _ctx))

        def begin_setPosY(self, thePosY, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_setPosY.begin(self, ((thePosY, ), _response, _ex, _sent, _ctx))

        def end_setPosY(self, _r):
            return _M_omero.model.WellSample._op_setPosY.end(self, _r)

        def getTimepoint(self, _ctx=None):
            return _M_omero.model.WellSample._op_getTimepoint.invoke(self, ((), _ctx))

        def begin_getTimepoint(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_getTimepoint.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTimepoint(self, _r):
            return _M_omero.model.WellSample._op_getTimepoint.end(self, _r)

        def setTimepoint(self, theTimepoint, _ctx=None):
            return _M_omero.model.WellSample._op_setTimepoint.invoke(self, ((theTimepoint, ), _ctx))

        def begin_setTimepoint(self, theTimepoint, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_setTimepoint.begin(self, ((theTimepoint, ), _response, _ex, _sent, _ctx))

        def end_setTimepoint(self, _r):
            return _M_omero.model.WellSample._op_setTimepoint.end(self, _r)

        def getPlateAcquisition(self, _ctx=None):
            return _M_omero.model.WellSample._op_getPlateAcquisition.invoke(self, ((), _ctx))

        def begin_getPlateAcquisition(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_getPlateAcquisition.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPlateAcquisition(self, _r):
            return _M_omero.model.WellSample._op_getPlateAcquisition.end(self, _r)

        def setPlateAcquisition(self, thePlateAcquisition, _ctx=None):
            return _M_omero.model.WellSample._op_setPlateAcquisition.invoke(self, ((thePlateAcquisition, ), _ctx))

        def begin_setPlateAcquisition(self, thePlateAcquisition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_setPlateAcquisition.begin(self, ((thePlateAcquisition, ), _response, _ex, _sent, _ctx))

        def end_setPlateAcquisition(self, _r):
            return _M_omero.model.WellSample._op_setPlateAcquisition.end(self, _r)

        def getWell(self, _ctx=None):
            return _M_omero.model.WellSample._op_getWell.invoke(self, ((), _ctx))

        def begin_getWell(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_getWell.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getWell(self, _r):
            return _M_omero.model.WellSample._op_getWell.end(self, _r)

        def setWell(self, theWell, _ctx=None):
            return _M_omero.model.WellSample._op_setWell.invoke(self, ((theWell, ), _ctx))

        def begin_setWell(self, theWell, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_setWell.begin(self, ((theWell, ), _response, _ex, _sent, _ctx))

        def end_setWell(self, _r):
            return _M_omero.model.WellSample._op_setWell.end(self, _r)

        def getImage(self, _ctx=None):
            return _M_omero.model.WellSample._op_getImage.invoke(self, ((), _ctx))

        def begin_getImage(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_getImage.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getImage(self, _r):
            return _M_omero.model.WellSample._op_getImage.end(self, _r)

        def setImage(self, theImage, _ctx=None):
            return _M_omero.model.WellSample._op_setImage.invoke(self, ((theImage, ), _ctx))

        def begin_setImage(self, theImage, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.WellSample._op_setImage.begin(self, ((theImage, ), _response, _ex, _sent, _ctx))

        def end_setImage(self, _r):
            return _M_omero.model.WellSample._op_setImage.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.WellSamplePrx.ice_checkedCast(proxy, '::omero::model::WellSample', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.WellSamplePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::WellSample'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_WellSamplePrx = IcePy.defineProxy('::omero::model::WellSample', WellSamplePrx)

    _M_omero.model._t_WellSample = IcePy.declareClass('::omero::model::WellSample')

    _M_omero.model._t_WellSample = IcePy.defineClass('::omero::model::WellSample', WellSample, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_posX', (), _M_omero.model._t_Length, False, 0),
        ('_posY', (), _M_omero.model._t_Length, False, 0),
        ('_timepoint', (), _M_omero._t_RTime, False, 0),
        ('_plateAcquisition', (), _M_omero.model._t_PlateAcquisition, False, 0),
        ('_well', (), _M_omero.model._t_Well, False, 0),
        ('_image', (), _M_omero.model._t_Image, False, 0)
    ))
    WellSample._ice_type = _M_omero.model._t_WellSample

    WellSample._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    WellSample._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    WellSample._op_getPosX = IcePy.Operation('getPosX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    WellSample._op_setPosX = IcePy.Operation('setPosX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    WellSample._op_getPosY = IcePy.Operation('getPosY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    WellSample._op_setPosY = IcePy.Operation('setPosY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    WellSample._op_getTimepoint = IcePy.Operation('getTimepoint', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    WellSample._op_setTimepoint = IcePy.Operation('setTimepoint', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    WellSample._op_getPlateAcquisition = IcePy.Operation('getPlateAcquisition', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PlateAcquisition, False, 0), ())
    WellSample._op_setPlateAcquisition = IcePy.Operation('setPlateAcquisition', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlateAcquisition, False, 0),), (), None, ())
    WellSample._op_getWell = IcePy.Operation('getWell', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Well, False, 0), ())
    WellSample._op_setWell = IcePy.Operation('setWell', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Well, False, 0),), (), None, ())
    WellSample._op_getImage = IcePy.Operation('getImage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Image, False, 0), ())
    WellSample._op_setImage = IcePy.Operation('setImage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Image, False, 0),), (), None, ())

    _M_omero.model.WellSample = WellSample
    del WellSample

    _M_omero.model.WellSamplePrx = WellSamplePrx
    del WellSamplePrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright 2011 - 2016 Glencoe Software, Inc. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt


"""
   User administration plugin (LDAP extension)
"""

from builtins import str
import sys

from omero.cli import CLI, ExceptionHandler, admin_only, UserGroupControl
from omero.model.enums import (
    AdminPrivilegeModifyGroup, AdminPrivilegeModifyGroupMembership,
    AdminPrivilegeModifyUser)
from omero.rtypes import rbool

HELP = """Administrative support for managing users' LDAP settings

Most of these commands should be run as an OMERO administrator such as root.

Examples:

  omero login root
  omero ldap active
  omero ldap list
  omero ldap getdn --user-name jack         # Get DN of user.
  omero ldap setdn --user-name jack true    # Enable LDAP login.
  omero ldap setdn --user-name jack false   # Disable LDAP login.
  omero ldap getdn --group-name mylab       # Get DN of user group.
  omero ldap setdn --group-name mylab true  # Mark group as LDAP group.
  omero ldap setdn --group-name mylab false # Mark group as local.
  omero ldap discover
  omero ldap discover --groups
  omero ldap create bob                     # User bob must exist in LDAP

"""


class LdapControl(UserGroupControl):

    def _configure(self, parser):

        self.exc = ExceptionHandler()

        sub = parser.sub()

        active = parser.add(
            sub, self.active,
            help="Return code shows if LDAP is configured (admins-only)")

        list = parser.add(
            sub, self.list,
            help="List all OMERO users with DNs")
        list.add_style_argument()

        getdn = parser.add(sub, self.getdn, help="Get DN for user on stdout")
        setdn = parser.add(
            sub, self.setdn,
            help="""Enable or disable LDAP login for user (admins only)

Once LDAP login is enabled for a user, the password set via OMERO is
ignored, and any attempt to change it will result in an error. When
you disable LDAP login, the previous password will be in effect, but if the
user never had a password, one will need to be set!""")

        for x in (getdn, setdn):
            self.add_user_and_group_arguments(x)
        setdn.add_argument("choice", action="store",
                           help="Enable/disable LDAP login (true/false)")

        discover = parser.add(
            sub, self.discover,
            help="""Discover DNs for existing OMERO users or groups

This command works in the context of users or groups. Specifying
--groups will only discover groups, that is check which group exists in
the LDAP server and OMERO and has the "ldap" flag disabled - such groups
will be presented to the user. Omitting --groups will apply the same logic
to users.""")
        discover.add_argument(
            "--commands", action="store_true", default=False,
            help="Print setdn commands on standard out")
        discover.add_argument("--groups", action="store_true", default=False,
                              help="Discover LDAP groups, not users.")

        create = parser.add(
            sub, self.create,
            help="Create a local user based on LDAP username (admins only)"
        )
        create.add_argument(
            "username", help="LDAP username of user to be created")

        for x in (active, list, getdn, setdn, discover, create):
            x.add_login_arguments()

    @admin_only(full_admin=False)  # IConfig privilege
    def active(self, args):
        c = self.ctx.conn(args)
        ildap = c.sf.getLdapService()

        if ildap.getSetting():
            self.ctx.out("Yes")
        else:
            self.ctx.die(1, "No")

    def list(self, args):
        c = self.ctx.conn(args)
        iadmin = c.sf.getAdminService()

        from omero.rtypes import unwrap
        from omero.util.text import TableBuilder
        list_of_dn_user_maps = unwrap(iadmin.lookupLdapAuthExperimenters())
        if list_of_dn_user_maps is None:
            return

        count = 0
        tb = TableBuilder("#")
        if args.style:
            tb.set_style(args.style)
        tb.cols(["Id", "OmeName", "DN"])
        for map in list_of_dn_user_maps:
            for dn, id in list(map.items()):
                try:
                    exp = iadmin.getExperimenter(id)
                except:
                    self.ctx.err("Bad experimenter: %s" % id)

                tb.row(count, *(id, exp.omeName.val, dn))
                count += 1
        self.ctx.out(str(tb.build()))

    @admin_only(full_admin=False)  # ILdap privilege
    def getdn(self, args):
        c = self.ctx.conn(args)
        iadmin = c.sf.getAdminService()
        ildap = c.sf.getLdapService()

        dn = None

        if args.user_name:
            [uid, u] = self.find_user_by_name(iadmin, args.user_name,
                                              fatal=True)
            if u and u.getLdap().val:
                name = u.getOmeName().val
                dn = name + ": " + ildap.findDN(name)
        elif args.user_id:
            [uid, u] = self.find_user_by_id(iadmin, args.user_id, fatal=True)
            if u and u.getLdap().val:
                name = u.getOmeName().val
                dn = name + ": " + ildap.findDN(name)
        elif args.group_name:
            [gid, g] = self.find_group_by_name(iadmin, args.group_name,
                                               fatal=True)
            if g and g.getLdap().val:
                name = g.getName().val
                dn = name + ": " + ildap.findGroupDN(name)
        elif args.group_id:
            [gid, g] = self.find_group_by_id(iadmin, args.group_id, fatal=True)
            if g and g.getLdap().val:
                name = g.getName().val
                dn = name + ": " + ildap.findGroupDN(name)

        if dn is not None and dn.strip():
            self.ctx.out(dn)

    @admin_only(AdminPrivilegeModifyGroup)
    def update_group(self, iupdate, group):
        iupdate.saveObject(group)

    @admin_only(AdminPrivilegeModifyUser)
    def update_user(self, iupdate, user):
        iupdate.saveObject(user)

    @admin_only(full_admin=False)  # See update_user/update_group
    def setdn(self, args):
        c = self.ctx.conn(args)
        iupdate = c.sf.getUpdateService()
        iadmin = c.sf.getAdminService()

        obj = None

        if args.user_name:
            [uid, obj] = self.find_user_by_name(iadmin, args.user_name,
                                                fatal=True)
        elif args.user_id:
            [uid, obj] = self.find_user_by_id(iadmin, args.user_id, fatal=True)
        elif args.group_name:
            [gid, obj] = self.find_group_by_name(iadmin, args.group_name,
                                                 fatal=True)
        elif args.group_id:
            [gid, obj] = self.find_group_by_id(iadmin, args.group_id,
                                               fatal=True)

        if obj is not None:
            from omero.model import Experimenter, ExperimenterGroup
            obj.setLdap(rbool(args.choice.lower()
                              in ("yes", "true", "t", "1")))
            if isinstance(obj, ExperimenterGroup):
                self.update_group(iupdate, obj)
            elif isinstance(obj, Experimenter):
                self.update_user(iupdate, obj)

    @admin_only(full_admin=False)  # ILdap privilege
    def discover(self, args):
        c = self.ctx.conn(args)
        ildap = c.sf.getLdapService()
        elements = {}
        element_name = "users"

        if args.groups:
            element_name = "groups"
            elements = ildap.discoverGroups()
        else:
            elements = ildap.discover()

        if len(elements) > 0:
            self.ctx.out("Following LDAP %s are disabled in OMERO:"
                         % element_name)
            for e in elements:
                if args.groups:
                    if args.commands:
                        self.ctx.out("%s ldap setdn --group-name %s true"
                                     % (sys.argv[0], e.getName().getValue()))
                    else:
                        self.ctx.out("Group=%s\tname=%s"
                                     % (e.getId().getValue(),
                                        e.getName().getValue()))
                else:
                    if args.commands:
                        self.ctx.out("%s ldap setdn --user-name %s true"
                                     % (sys.argv[0],
                                        e.getOmeName().getValue()))
                    else:
                        self.ctx.out("Experimenter=%s\tomeName=%s"
                                     % (e.getId().getValue(),
                                        e.getOmeName().getValue()))

    @admin_only(AdminPrivilegeModifyUser, AdminPrivilegeModifyGroupMembership)
    def create(self, args):
        c = self.ctx.conn(args)
        ildap = c.sf.getLdapService()
        iadmin = c.sf.getAdminService()

        import omero
        import Ice
        try:
            exp = ildap.createUser(args.username)
            dn = iadmin.lookupLdapAuthExperimenter(exp.id.val)
            self.ctx.out("Added user %s (id=%s) with DN=%s" %
                         (exp.omeName.val, exp.id.val, dn))
        except omero.ValidationException as ve:
            self.ctx.die(132, ve.message)
        except Ice.RequestFailedException as rfe:
            self.ctx.die(133, self.exc.handle_failed_request(rfe))

try:
    register("ldap", LdapControl, HELP)
except NameError:
    if __name__ == "__main__":
        cli = CLI()
        cli.register("ldap", LdapControl, HELP)
        cli.invoke(sys.argv[1:])



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (C) 2016 University of Dundee & Open Microscopy Environment.
# All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

"""
Utilities for manipulating map-annotations used as metadata
"""

from builtins import str
from builtins import range
from builtins import object
import logging
from omero.model import NamedValue
from omero.rtypes import rstring, unwrap
# For complicated reasons `from omero.sys import ParametersI` doesn't work
from omero_sys_ParametersI import ParametersI

log = logging.getLogger("omero.util.metadata_mapannotations")


class MapAnnotationPrimaryKeyException(Exception):

    def __init__(self, message):
        super(MapAnnotationPrimaryKeyException, self).__init__(message)


class CanonicalMapAnnotation(object):
    """
    A canonical representation of a map-annotation for metadata use
    This is based around the idea of a primary key derived from the
    combination of the namespace with 1+ keys-value pairs. A null
    namespace is treated as an empty string (''), but still forms part
    of the primary key.

    :param ma: The omero.model.MapAnnotation object
    :param primary_keys: Keys from key-value pairs that will be used to form the primary key.
    """

    def __init__(self, ma, primary_keys=None):
        # TODO: should we consider data and description
        self.ma = ma
        ns = unwrap(ma.getNs())
        self.ns = ns if ns else ''
        try:
            mapvalue = [(kv.name, kv.value) for kv in ma.getMapValue()]
        except TypeError:
            mapvalue = []
        self.kvpairs, self.primary = self.process_keypairs(
            mapvalue, primary_keys)
        self.parents = set()

    def process_keypairs(self, kvpairs, primary_keys):
        if len(set(kvpairs)) != len(kvpairs):
            raise ValueError('Duplicate key-value pairs found: %s' % kvpairs)

        if primary_keys:
            primary_keys = set(primary_keys)
            missing = primary_keys.difference(kv[0] for kv in kvpairs)
            if missing:
                raise MapAnnotationPrimaryKeyException(
                    'Missing primary key fields: %s' % missing)
            # ns is always part of the primary key
            primary = (
                self.ns,
                frozenset((k, v) for (k, v) in kvpairs if k in primary_keys))
        else:
            primary = None

        return kvpairs, primary

    def merge(self, other):
        """
        Adds any key/value pairs from other that aren't in self
        Adds parents from other
        Does not update primary key
        """
        if self.kvpairs != other.kvpairs:
            kvpairsset = set(self.kvpairs)
            for okv in other.kvpairs:
                if okv not in kvpairsset:
                    self.kvpairs.append(okv)
        self.merge_parents(other)

    def merge_parents(self, other):
        self.parents.update(other.parents)

    def add_parent(self, parenttype, parentid):
        """
        Add a parent descriptor
        Parameter types are important because they are used in a set

        :param parenttype: An OMERO type string
        :param parentid: An OMERO object ID (integer)
        """
        if not isinstance(parenttype, str) or not isinstance(
                parentid, int):
            raise ValueError('Expected parenttype:str parentid:integer')
        self.parents.add((parenttype, parentid))

    def get_mapann(self):
        """
        Update and return an omero.model.MapAnnotation with merged/combined
        fields
        """
        mv = [NamedValue(*kv) for kv in self.kvpairs]
        self.ma.setMapValue(mv)
        self.ma.setNs(rstring(self.ns))
        return self.ma

    def get_parents(self):
        return self.parents

    def __str__(self):
        return 'ns:%s primary:%s keyvalues:%s parents:%s id:%s' % (
            self.ns, self.primary, self.kvpairs, self.parents,
            unwrap(self.ma.getId()))


class MapAnnotationManager(object):
    """
    Handles creation and de-duplication of MapAnnotations
    """
    # Policies for combining/replacing MapAnnotations
    MA_APPEND, MA_OLD, MA_NEW = list(range(3))

    def __init__(self, combine=MA_APPEND):
        """
        Ensure you understand the doc string for init_from_namespace_query
        if not using MA_APPEND
        """
        self.mapanns = {}
        self.nokey = []
        self.combine = combine

    def add(self, cma):
        """
        Adds a CanonicalMapAnnotation to the managed list.

        Returns any CanonicalMapAnnotation that are no longer required,
        this may be cma or it may be a previously added annotation.
        The idea is that this can be used to de-duplicate existing OMERO
        MapAnnotations by calling add() on all MapAnnotations and deleting
        those which are returned

        If MapAnnotations are combined the parents of the unwanted
        MapAnnotations are appended to the one that is kept by the manager.

        :param cma: A CanonicalMapAnnotation
        """

        if cma.primary is None:
            self.nokey.append(cma)
            return

        try:
            current = self.mapanns[cma.primary]
            if current.ma is cma.ma:
                # Don't re-add an identical object
                return
            if self.combine == self.MA_APPEND:
                current.merge(cma)
                return cma
            if self.combine == self.MA_NEW:
                self.mapanns[cma.primary] = cma
                cma.merge_parents(current)
                return current
            if self.combine == self.MA_OLD:
                current.merge_parents(cma)
                return cma
            raise ValueError('Invalid combine policy')
        except KeyError:
            self.mapanns[cma.primary] = cma

    def get_map_annotations(self):
        return list(self.mapanns.values()) + self.nokey

    def add_from_namespace_query(self, session, ns, primary_keys):
        """
        Fetches all map-annotations with the given namespace
        This will only work if there are no duplicates, otherwise an
        exception will be thrown

        WARNING: You should probably only use this in MA_APPEND mode since
        the parents of existing annotations aren't fetched (requires a query
        for each parent type)
        WARNING: This may be resource intensive
        TODO: Use omero.utils.populate_metadata._QueryContext for batch queries

        :param session: An OMERO session
        :param ns: The namespace
        :param primary_keys: Primary keys
        """
        qs = session.getQueryService()
        q = 'FROM MapAnnotation WHERE ns=:ns ORDER BY id DESC'
        p = ParametersI()
        p.addString('ns', ns)
        results = qs.findAllByQuery(q, p)
        log.debug('Found %d MapAnnotations in ns:%s', len(results), ns)
        for ma in results:
            cma = CanonicalMapAnnotation(ma, primary_keys)
            r = self.add(cma)
            if r:
                raise Exception(
                    'Duplicate MapAnnotation primary key: id:%s %s' % (
                        unwrap(ma.getId()), str(r)))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
   Copyright 2008-2020 The Open Microscopy Environment, Glencoe Software, Inc.
   All rights reserved.

   Use is subject to license terms supplied in LICENSE.txt
"""
from __future__ import print_function

import glob
import sys
import os

from setuptools import (
    Command,
    setup,
    find_packages,
)

try:
    from StringIO import StringIO
    from StringIO import StringIO as BytesIO
except ImportError:
    # Python 3
    from io import StringIO
    from io import BytesIO

from shutil import (
    copy,
    rmtree,
)

try:
    from urllib.request import urlopen
except ImportError:
    # Python 2
    from urllib import urlopen
from zipfile import ZipFile

try:
    import configparser
except ImportError:
    # Python 2
    import ConfigParser as configparser


def get_blitz_location():

    config_blitz_version = "5.5.5"

    # simplified strings
    defaultsect = configparser.DEFAULTSECT
    version_key = "versions.omero-blitz"
    url_key = "versions.omero-blitz-url"

    # detect if in Jenkins or not
    if "ZIP_FILE" in os.environ:
        config_blitz_url = os.environ.get("ZIP_FILE")
    elif "JENKINS_URL" in os.environ:
        config_blitz_url = os.environ.get("JENKINS_URL")
        config_blitz_url += "job/OMERO-build-build/lastSuccessfulBuild/"
        config_blitz_url += "artifact/omero-blitz/build/distributions/"
        config_blitz_url += "omero-blitz-VERSION-python.zip"
    else:
        config_blitz_url = (
            "https://artifacts.openmicroscopy.org/artifactory/ome.releases/"
            "org/openmicroscopy/omero-blitz/VERSION/"
            "omero-blitz-VERSION-python.zip")

    # load version.properties if available
    config_path = os.environ.get("VERSION_PROPERTIES",
                                 "artifact/version.properties")
    if os.path.exists(config_path):
        config_obj = configparser.RawConfigParser({
            url_key: config_blitz_url,
            version_key: config_blitz_version,
        })
        with open(config_path) as f:
            config_str = StringIO('[%s]\n%s' % (defaultsect, f.read()))
        config_obj.readfp(config_str)
        config_blitz_url = config_obj.get(defaultsect, url_key)
        config_blitz_version = config_obj.get(defaultsect, version_key)

    # replace VERSION in the final url and return
    config_blitz_url = config_blitz_url.replace(
            "VERSION", config_blitz_version)
    return config_blitz_url


def download_blitz_target():
    loc = get_blitz_location()
    if "ZIP_FILE" in os.environ:
        zipfile = ZipFile(loc)
    else: 
        print("Downloading %s ..." % loc, file=sys.stderr)
        resp = urlopen(loc)
        content = resp.read()
        content = BytesIO(content)
        zipfile = ZipFile(content)
    zipfile.extractall("target")


def _relative_symlink_file(src, dst):
    relsrc = os.path.relpath(src, os.path.dirname(dst))
    try:
        os.symlink(relsrc, dst)
        print(src, dst)
    except OSError as e:
        if e.errno != 17:
            raise
        os.remove(dst)
        os.symlink(relsrc, dst)


def copy_src_to_target(symlink=False):
    for dirpath, dirs, files in os.walk("src"):
        for filename in files:
            topath = dirpath.replace("src", "target", 1)
            if not os.path.exists(topath):
                os.makedirs(topath)
            fromfile = os.path.sep.join([dirpath, filename])
            tofile = os.path.sep.join([topath, filename])
            if symlink:
                _relative_symlink_file(fromfile, tofile)
            else:
                copy(fromfile, tofile)


# https://coderwall.com/p/3q_czg/custom-subcommand-at-setup-py
class DevTargetCommand(Command):
    """
    Recreate "target" with symlinks to files in "src" to ease development.

    For example, `pip install -e .` will work.
    Changes in files under "src" will be automatically seen in the installed
    module.

    If you add or remove files in src you must re-run both of these commands:

        python setup.py devtarget
        pip install -e .
    """

    description = (
        'Recreate target with symlinks to files in src to ease development')
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        rmtree('target')
        download_blitz_target()
        copy_src_to_target(symlink=True)
        print("If this is installed as an editable module re-run "
              "`pip install -e .`")


if not os.path.exists('target') and not "NO_ZIP_FILE" in os.environ:
    download_blitz_target()
    copy_src_to_target()


packageless = glob.glob("target/*.py")
packageless = [x[7:-3] for x in packageless]
packages = find_packages(where="target")

sys.path.append("target")
from omero_version import omero_version as ov  # noqa


def read(fname):
    """
    Utility function to read the README file.
    :rtype : String
    """
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name="omero-py",
    version=ov,
    description="Python bindings to the OMERO.blitz server",
    long_description=read("README.rst"),
    classifiers=[
      'Development Status :: 5 - Production/Stable',
      'Intended Audience :: Developers',
      'Intended Audience :: Science/Research',
      'Intended Audience :: System Administrators',
      'License :: OSI Approved :: GNU General Public License v2 '
      'or later (GPLv2+)',
      'Natural Language :: English',
      'Operating System :: OS Independent',
      'Programming Language :: Python :: 3',
      'Topic :: Software Development :: Libraries :: Python Modules',
    ],  # Get strings from
        # http://pypi.python.org/pypi?%3Aaction=list_classifiers
    author="The Open Microscopy Team",
    author_email="ome-devel@lists.openmicroscopy.org.uk",
    url='https://github.com/ome/omero-py',
    project_urls={
        'Documentation':
            'https://docs.openmicroscopy.org/omero/latest/developers/'
            'Python.html',
        'Bug tracker': 'https://github.com/ome/omero-py/issues',
        'API': 'https://omero-py.readthedocs.io/',
    },
    package_dir={"": "target"},
    packages=packages,
    package_data={
        'omero.gateway': ['pilfonts/*'],
        'omero.gateway.scripts': ['imgs/*']},
    py_modules=packageless,
    entry_points={
        'console_scripts': ['omero=omero.main:main'],
    },
    python_requires='>=3',
    install_requires=[
        'urllib3<2',
        'appdirs',
        'future',
        'numpy',
        'Pillow',
        'PyYAML',
        'zeroc-ice>=3.6.5,<3.7',
        'pywin32; platform_system=="Windows"',
        'requests',
        'portalocker'
    ],
    tests_require=[
        'pytest',
        'mox3',
    ],
    cmdclass={
        'devtarget': DevTargetCommand,
    },
)



"""
   /*
   **   Generated by blitz/resources/templates/combined.vm
   **
   **   Copyright 2007, 2008 Glencoe Software, Inc. All rights reserved.
   **   Use is subject to license terms supplied in LICENSE.txt
   **
   */
"""
try:
   unicode
except NameError:
   # Python 3: "unicode" is built-in
   unicode = str
import Ice
import IceImport
import omero
IceImport.load("omero_model_DetailsI")
IceImport.load("omero_model_RenderingDef_ice")
from omero.rtypes import rlong
from collections import namedtuple
_omero = Ice.openModule("omero")
_omero_model = Ice.openModule("omero.model")
__name__ = "omero.model"
class RenderingDefI(_omero_model.RenderingDef):

      # Property Metadata
      _field_info_data = namedtuple("FieldData", ["wrapper", "nullable"])
      _field_info_type = namedtuple("FieldInfo", [
          "pixels",
          "defaultZ",
          "defaultT",
          "model",
          "waveRendering",
          "name",
          "compression",
          "quantization",
          "projections",
          "details",
      ])
      _field_info = _field_info_type(
          pixels=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          defaultZ=_field_info_data(wrapper=omero.rtypes.rint, nullable=False),
          defaultT=_field_info_data(wrapper=omero.rtypes.rint, nullable=False),
          model=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          waveRendering=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          name=_field_info_data(wrapper=omero.rtypes.rstring, nullable=True),
          compression=_field_info_data(wrapper=omero.rtypes.rdouble, nullable=True),
          quantization=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          projections=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          details=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
      )  # end _field_info
      PIXELS =  "ome.model.display.RenderingDef_pixels"
      DEFAULTZ =  "ome.model.display.RenderingDef_defaultZ"
      DEFAULTT =  "ome.model.display.RenderingDef_defaultT"
      MODEL =  "ome.model.display.RenderingDef_model"
      WAVERENDERING =  "ome.model.display.RenderingDef_waveRendering"
      NAME =  "ome.model.display.RenderingDef_name"
      COMPRESSION =  "ome.model.display.RenderingDef_compression"
      QUANTIZATION =  "ome.model.display.RenderingDef_quantization"
      PROJECTIONS =  "ome.model.display.RenderingDef_projections"
      DETAILS =  "ome.model.display.RenderingDef_details"
      def errorIfUnloaded(self):
          if not self._loaded:
              raise _omero.UnloadedEntityException("Object unloaded:"+str(self))

      def throwNullCollectionException(self,propertyName):
          raise _omero.UnloadedEntityException(""+
          "Error updating collection:" + propertyName +"\n"+
          "Collection is currently null. This can be seen\n" +
          "by testing \""+ propertyName +"Loaded\". This implies\n"+
          "that this collection was unloaded. Please refresh this object\n"+
          "in order to update this collection.\n")

      def _toggleCollectionsLoaded(self, load):
          if load:
              self._waveRenderingSeq = []
              self._waveRenderingLoaded = True;
          else:
              self._waveRenderingSeq = []
              self._waveRenderingLoaded = False;

          if load:
              self._projectionsSeq = []
              self._projectionsLoaded = True;
          else:
              self._projectionsSeq = []
              self._projectionsLoaded = False;

          pass

      def __init__(self, id=None, loaded=None):
          super(RenderingDefI, self).__init__()
          if id is not None and isinstance(id, (str, unicode)) and ":" in id:
              parts = id.split(":")
              if len(parts) != 2:
                  raise Exception("Invalid proxy string: %s", id)
              if parts[0] != self.__class__.__name__ and \
                 parts[0]+"I" != self.__class__.__name__:
                  raise Exception("Proxy class mismatch: %s<>%s" %
                  (self.__class__.__name__, parts[0]))
              self._id = rlong(parts[1])
              if loaded is None:
                  # If no loadedness was requested with
                  # a proxy string, then assume False.
                  loaded = False
          else:
              # Relying on omero.rtypes.rlong's error-handling
              self._id = rlong(id)
              if loaded is None:
                  loaded = True  # Assume true as previously
          self._loaded = loaded
          if self._loaded:
             self._details = _omero_model.DetailsI()
             self._toggleCollectionsLoaded(True)

      def unload(self, current = None):
          self._loaded = False
          self.unloadPixels( )
          self.unloadDefaultZ( )
          self.unloadDefaultT( )
          self.unloadModel( )
          self.unloadWaveRendering( )
          self.unloadName( )
          self.unloadCompression( )
          self.unloadQuantization( )
          self.unloadProjections( )
          self.unloadDetails( )

      def isLoaded(self, current = None):
          return self._loaded
      def unloadCollections(self, current = None):
          self._toggleCollectionsLoaded( False )
      def isGlobal(self, current = None):
          return  False ;
      def isMutable(self, current = None):
          return  True ;
      def isAnnotated(self, current = None):
          return  False ;
      def isLink(self, current = None):
          return  False ;
      def shallowCopy(self, current = None):
            if not self._loaded: return self.proxy()
            copy = RenderingDefI()
            copy._id = self._id;
            copy._version = self._version;
            copy._details = None  # Unloading for the moment.
            raise omero.ClientError("NYI")
      def proxy(self, current = None):
          if self._id is None: raise omero.ClientError("Proxies require an id")
          return RenderingDefI( self._id.getValue(), False )

      def getDetails(self, current = None):
          self.errorIfUnloaded()
          return self._details

      def unloadDetails(self, current = None):
          self._details = None

      def getId(self, current = None):
          return self._id

      def setId(self, _id, current = None):
          self._id = _id

      def checkUnloadedProperty(self, value, loadedField):
          if value == None:
              self.__dict__[loadedField] = False
          else:
              self.__dict__[loadedField] = True

      def getVersion(self, current = None):
          self.errorIfUnloaded()
          return self._version

      def setVersion(self, version, current = None):
          self.errorIfUnloaded()
          self._version = version

      def unloadPixels(self, ):
          self._pixelsLoaded = False
          self._pixels = None;

      def getPixels(self, current = None):
          self.errorIfUnloaded()
          return self._pixels

      def setPixels(self, _pixels, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.pixels.wrapper is not None:
              if _pixels is not None:
                  _pixels = self._field_info.pixels.wrapper(_pixels)
          self._pixels = _pixels
          pass

      def unloadDefaultZ(self, ):
          self._defaultZLoaded = False
          self._defaultZ = None;

      def getDefaultZ(self, current = None):
          self.errorIfUnloaded()
          return self._defaultZ

      def setDefaultZ(self, _defaultZ, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.defaultZ.wrapper is not None:
              if _defaultZ is not None:
                  _defaultZ = self._field_info.defaultZ.wrapper(_defaultZ)
          self._defaultZ = _defaultZ
          pass

      def unloadDefaultT(self, ):
          self._defaultTLoaded = False
          self._defaultT = None;

      def getDefaultT(self, current = None):
          self.errorIfUnloaded()
          return self._defaultT

      def setDefaultT(self, _defaultT, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.defaultT.wrapper is not None:
              if _defaultT is not None:
                  _defaultT = self._field_info.defaultT.wrapper(_defaultT)
          self._defaultT = _defaultT
          pass

      def unloadModel(self, ):
          self._modelLoaded = False
          self._model = None;

      def getModel(self, current = None):
          self.errorIfUnloaded()
          return self._model

      def setModel(self, _model, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.model.wrapper is not None:
              if _model is not None:
                  _model = self._field_info.model.wrapper(_model)
          self._model = _model
          pass

      def unloadWaveRendering(self, current = None):
          self._waveRenderingLoaded = False
          self._waveRenderingSeq = None;

      def _getWaveRendering(self, current = None):
          self.errorIfUnloaded()
          return self._waveRenderingSeq

      def _setWaveRendering(self, _waveRendering, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.waveRenderingSeq.wrapper is not None:
              if _waveRendering is not None:
                  _waveRendering = self._field_info.waveRenderingSeq.wrapper(_waveRendering)
          self._waveRenderingSeq = _waveRendering
          self.checkUnloadedProperty(_waveRendering,'waveRenderingLoaded')

      def isWaveRenderingLoaded(self):
          return self._waveRenderingLoaded

      def sizeOfWaveRendering(self, current = None):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: return -1
          return len(self._waveRenderingSeq)

      def copyWaveRendering(self, current = None):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          return list(self._waveRenderingSeq)

      def iterateWaveRendering(self):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          return iter(self._waveRenderingSeq)

      def addChannelBinding(self, target, current = None):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          self._waveRenderingSeq.append( target );
          target.setRenderingDef( self )

      def addAllChannelBindingSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          self._waveRenderingSeq.extend( targets )
          for target in targets:
              target.setRenderingDef( self )

      def removeChannelBinding(self, target, current = None):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          self._waveRenderingSeq.remove( target )
          target.setRenderingDef( None )

      def removeAllChannelBindingSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          for elt in targets:
              elt.setRenderingDef( None )
              self._waveRenderingSeq.remove( elt )

      def clearWaveRendering(self, current = None):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          for elt in self._waveRenderingSeq:
              elt.setRenderingDef( None )
          self._waveRenderingSeq = list()

      def reloadWaveRendering(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._waveRenderingLoaded:
              raise omero.ClientError("Cannot reload active collection: waveRenderingSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyWaveRendering() # May also throw
          for elt in copy:
              elt.setRenderingDef( self )
          self._waveRenderingSeq = copy
          toCopy.unloadWaveRendering()
          self._waveRenderingLoaded = True

      def getChannelBinding(self, index, current = None):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          return self._waveRenderingSeq[index]

      def setChannelBinding(self, index, element, current = None, wrap=False):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          old = self._waveRenderingSeq[index]
          if wrap and self._field_info.waveRenderingSeq.wrapper is not None:
              if element is not None:
                  element = self._field_info.waveRenderingSeq.wrapper(_waveRendering)
          self._waveRenderingSeq[index] =  element
          if element is not None and element.isLoaded():
              element.setRenderingDef( self )
          return old

      def getPrimaryChannelBinding(self, current = None):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          return self._waveRenderingSeq[0]

      def setPrimaryChannelBinding(self, element, current = None):
          self.errorIfUnloaded()
          if not self._waveRenderingLoaded: self.throwNullCollectionException("waveRenderingSeq")
          index = self._waveRenderingSeq.index(element)
          old = self._waveRenderingSeq[0]
          self._waveRenderingSeq[index] = old
          self._waveRenderingSeq[0] = element
          return old

      def unloadName(self, ):
          self._nameLoaded = False
          self._name = None;

      def getName(self, current = None):
          self.errorIfUnloaded()
          return self._name

      def setName(self, _name, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.name.wrapper is not None:
              if _name is not None:
                  _name = self._field_info.name.wrapper(_name)
          self._name = _name
          pass

      def unloadCompression(self, ):
          self._compressionLoaded = False
          self._compression = None;

      def getCompression(self, current = None):
          self.errorIfUnloaded()
          return self._compression

      def setCompression(self, _compression, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.compression.wrapper is not None:
              if _compression is not None:
                  _compression = self._field_info.compression.wrapper(_compression)
          self._compression = _compression
          pass

      def unloadQuantization(self, ):
          self._quantizationLoaded = False
          self._quantization = None;

      def getQuantization(self, current = None):
          self.errorIfUnloaded()
          return self._quantization

      def setQuantization(self, _quantization, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.quantization.wrapper is not None:
              if _quantization is not None:
                  _quantization = self._field_info.quantization.wrapper(_quantization)
          self._quantization = _quantization
          pass

      def unloadProjections(self, current = None):
          self._projectionsLoaded = False
          self._projectionsSeq = None;

      def _getProjections(self, current = None):
          self.errorIfUnloaded()
          return self._projectionsSeq

      def _setProjections(self, _projections, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.projectionsSeq.wrapper is not None:
              if _projections is not None:
                  _projections = self._field_info.projectionsSeq.wrapper(_projections)
          self._projectionsSeq = _projections
          self.checkUnloadedProperty(_projections,'projectionsLoaded')

      def isProjectionsLoaded(self):
          return self._projectionsLoaded

      def sizeOfProjections(self, current = None):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: return -1
          return len(self._projectionsSeq)

      def copyProjections(self, current = None):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          return list(self._projectionsSeq)

      def iterateProjections(self):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          return iter(self._projectionsSeq)

      def addProjectionDef(self, target, current = None):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          self._projectionsSeq.append( target );
          target.setRenderingDef( self )

      def addAllProjectionDefSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          self._projectionsSeq.extend( targets )
          for target in targets:
              target.setRenderingDef( self )

      def removeProjectionDef(self, target, current = None):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          self._projectionsSeq.remove( target )
          target.setRenderingDef( None )

      def removeAllProjectionDefSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          for elt in targets:
              elt.setRenderingDef( None )
              self._projectionsSeq.remove( elt )

      def clearProjections(self, current = None):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          for elt in self._projectionsSeq:
              elt.setRenderingDef( None )
          self._projectionsSeq = list()

      def reloadProjections(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._projectionsLoaded:
              raise omero.ClientError("Cannot reload active collection: projectionsSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyProjections() # May also throw
          for elt in copy:
              elt.setRenderingDef( self )
          self._projectionsSeq = copy
          toCopy.unloadProjections()
          self._projectionsLoaded = True

      def getProjectionDef(self, index, current = None):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          return self._projectionsSeq[index]

      def setProjectionDef(self, index, element, current = None, wrap=False):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          old = self._projectionsSeq[index]
          if wrap and self._field_info.projectionsSeq.wrapper is not None:
              if element is not None:
                  element = self._field_info.projectionsSeq.wrapper(_projections)
          self._projectionsSeq[index] =  element
          if element is not None and element.isLoaded():
              element.setRenderingDef( self )
          return old

      def getPrimaryProjectionDef(self, current = None):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          return self._projectionsSeq[0]

      def setPrimaryProjectionDef(self, element, current = None):
          self.errorIfUnloaded()
          if not self._projectionsLoaded: self.throwNullCollectionException("projectionsSeq")
          index = self._projectionsSeq.index(element)
          old = self._projectionsSeq[0]
          self._projectionsSeq[index] = old
          self._projectionsSeq[0] = element
          return old


      def ice_postUnmarshal(self):
          """
          Provides additional initialization once all data loaded
          """
          pass # Currently unused


      def ice_preMarshal(self):
          """
          Provides additional validation before data is sent
          """
          pass # Currently unused

      def __getattr__(self, name):
          """
          Reroutes all access to object.field through object.getField() or object.isField()
          """
          if "_" in name:  # Ice disallows underscores, so these should be treated normally.
              return object.__getattribute__(self, name)
          field  = "_" + name
          capitalized = name[0].capitalize() + name[1:]
          getter = "get" + capitalized
          questn = "is" + capitalized
          try:
              self.__dict__[field]
              if hasattr(self, getter):
                  method = getattr(self, getter)
                  return method()
              elif hasattr(self, questn):
                  method = getattr(self, questn)
                  return method()
          except:
              pass
          raise AttributeError("'%s' object has no attribute '%s' or '%s'" % (self.__class__.__name__, getter, questn))

      def __setattr__(self, name, value):
          """
          Reroutes all access to object.field through object.getField(), with the caveat
          that all sets on variables starting with "_" are permitted directly.
          """
          if name.startswith("_"):
              self.__dict__[name] = value
              return
          else:
              field  = "_" + name
              setter = "set" + name[0].capitalize() + name[1:]
              if hasattr(self, field) and hasattr(self, setter):
                  method = getattr(self, setter)
                  return method(value)
          raise AttributeError("'%s' object has no attribute '%s'" % (self.__class__.__name__, setter))

_omero_model.RenderingDefI = RenderingDefI
